#
# spec file for package libsodium
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define lname libsodium13
Name:           libsodium
Version:        1.0.3
Release:        5.5
Summary:        Portable NaCl-based crypto library
License:        ISC
Group:          System/Libraries
Url:            https://github.com/jedisct1/libsodium
Source:         https://github.com/jedisct1/libsodium/releases/download/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
NaCl (pronounced "salt") is a new easy-to-use high-speed software library
for network communication, encryption, decryption, signatures, etc.NaCl's goal
is to provide all of the core operations needed to build higher-level cryptographic tools.

Sodium is a portable, cross-compilable, installable, packageable fork of NaCl,
with a compatible API.

%package -n  %{lname}
Summary:        Portable NaCl-based crypto library
Group:          System/Libraries

%description -n %{lname}
NaCl (pronounced "salt") is a new easy-to-use high-speed software library
for network communication, encryption, decryption, signatures, etc. NaCl's goal
is to provide all of the core operations needed to build higher-level cryptographic tools.

Sodium is a portable, cross-compilable, installable, packageable fork of NaCl,
with a compatible API.

%package devel
Summary:        Portable NaCl-based crypto library
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
This package contains all necessary include files and libraries needed
to compile and develop applications that use libsodium.

%prep
%setup -q

%build
%configure --disable-static
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}

find %{buildroot} -type f -name "*.la" -delete -print

%check
make %{?_smp_mflags} check

%post -n %{lname} -p /sbin/ldconfig

%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%defattr(0644,root,root,0755)
%{_libdir}/libsodium.so.*

%files devel
%defattr(-,root,root)
%doc AUTHORS ChangeLog LICENSE README.markdown THANKS
%{_includedir}/sodium.h
%{_includedir}/sodium
%{_libdir}/libsodium.so
%{_libdir}/pkgconfig/libsodium.pc

%changelog
* Wed May 13 2015 mpluskal@suse.com
- Update to 1.0.3
  * In addition to sodium_bin2hex(), sodium_hex2bin() is now a
    constant-time function.
  * crypto_stream_xsalsa20_ic() has been added.
  * crypto_generichash_statebytes(), crypto_auth_*_statebytes()
    and crypto_hash_*_statebytes() have been added in order to
    retrieve the size of structures keeping states from foreign
    languages.
  * The JavaScript target doesn't require /dev/urandom or an
    external randombytes() implementation any more. Other minor
    Emscripten-related improvements have been made in order to
    support libsodium.js
  * Custom randombytes implementations do not need to provide
    their own implementation of randombytes_uniform() any more.
    randombytes_stir() and randombytes_close() can also be NULL
    pointers if they are not required.
  * On Linux, getrandom(2) is being used instead of directly
    accessing /dev/urandom, if the kernel supports this system
    call.
  * crypto_box_seal() and crypto_box_seal_open() have been added.
  * A solutions for Visual Studio 2015 was added.
* Fri Jan 16 2015 idonmez@suse.com
- Update to version 1.0.2
  * The _easy and _detached APIs now support precalculated keys
  * sodium_free() can now be called on regions with PROT_NONE
    protection.
  * Memory allocation functions can now be used on operating systems
    with no memory protection.
* Wed Sep 24 2014 idonmez@suse.com
- Update to version 1.0.0
  * The API and ABI are now stable.
  * crypto_sign() properly works with overlapping regions again.
  * The test suite has been extended.
* Thu Aug 28 2014 idonmez@suse.com
- Update to version 0.7.0
  * Added sodium_malloc() and sodium_allocarray() for secure memory
    allocation.
  * ed25519 keys can be converted to curve25519 keys with
    crypto_sign_ed25519_pk_to_curve25519() and
    crypto_sign_ed25519_sk_to_curve25519().
  * aes256 was removed.
* Wed Jul 16 2014 idonmez@suse.com
- Update to version 0.6.1
  * The ChaCha20 stream cipher has been added
  * The ChaCha20Poly1305 AEAD construction has been implemented
  * crypto_onetimeauth() now provides a streaming interface.
  * New API: crypto_sign_detached() and crypto_sign_verify_detached()
* Wed May 14 2014 idonmez@suse.com
- Update to version 0.5.0
  * sodium_mlock()/sodium_munlock() have been introduced.
  * Added high-level wrappers for crypto_box and crypto_secretbox
  * Added crypto_pwhash_scryptxsalsa208sha256* functions
  * Salsa20 and ed25519 implementations now support overlapping
    inputs/keys/outputs
  * The poly1305-53 implementation has been replaced with Floodyberry's
    poly1305-donna32 and poly1305-donna64 implementations
  * sodium_hex2bin() has been added to complement sodium_bin2hex()
  * crypto_auth_hmac_sha512() has been implemented
  * sha256 and sha512 now have a streaming interface
  * hmacsha256, hmacsha512 and hmacsha512256 now support keys of
    arbitrary length, and have a streaming interface
  * crypto_verify_64() has been implemented
  * CPU features are now detected at runtime
* Fri May  2 2014 i@marguerite.su
- Update to version 0.4.5
  * Restore compatibility with OSX <= 10.6
* Tue Oct 22 2013 idonmez@suse.com
- Update to version 0.4.4
  * Big-endian architectures are now supported.
  * The donna_c64 implementation of curve25519_donna_c64 now handles
    non-canonical points like the ref implementation.
  * Missing scalarmult_curve25519 and stream_salsa20 constants are
    now exported.
  * A crypto_onetimeauth_poly1305_ref() wrapper has been added.
* Wed Sep 11 2013 idonmez@suse.com
- Initial release for build.opensuse.org
